# ConnectionStep

Contained in a Source or Destination Report Card object, the Connection Steps object contains the steps necessary to configure a data source or destination.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** | The type of step | [optional]
**properties** | [**list[ConnectionStepProps]**](ConnectionStepProps.md) | The destination connection type. For example: postgres or redshift  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


